:orphan:

API
===

The following modules are documented for those who wish to extend natu,
understand its internal design, or interface with it at a low level:

- :mod:`natu.core` - Core classes of natu
- :mod:`natu.exponents` - Class with methods to represent and operate on the
  product of factors with exponents
- :mod:`natu.util` - General supporting functions
